Summary:       To provide a high-level device independent layer for speech synthesis
Name:          speech-dispatcher
Version:       0.11.4
Release:       7%{?dist}
License:       GPLv2+ and LGPLv2
URL:           http://devel.freebsoft.org/speechd
Source0:       https://github.com/brailcom/speechd/releases/download/%{version}/speech-dispatcher-%{version}.tar.gz
Source1:       http://www.freebsoft.org/pub/projects/sound-icons/sound-icons-0.1.tar.gz

Patch3000:     0001-Remove-pyxdg-dependency.patch

BuildRequires: alsa-lib-devel desktop-file-utils dotconf-devel espeak-ng-devel flite-devel
BuildRequires: gcc gcc-c++ glib2-devel help2man intltool libao-devel libtool-ltdl-devel
Buildrequires: libsndfile-devel make pulseaudio-libs-devel python3-devel python3-setuptools systemd texinfo
Requires:      speech-dispatcher-espeak-ng
%{?systemd_requires}

%description
* Common interface to different TTS engines
* Handling concurrent synthesis requests – requests may come asynchronously from multiple sources
  within an application and/or from more different applications.
* Subsequent serialization, resolution of conflicts and priorities of incoming requests
* Context switching – state is maintained for each client connection independently, event for
  connections from within one application.
* High-level client interfaces for popular programming languages
* Common sound output handling – audio playback is handled by Speech Dispatcher rather than the TTS
  engine, since most engines have limited sound output capabilities.

%package        devel
Summary:        Development files for %{name}
License:        GPLv2+
Requires:       %{name} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for developing applications that use %{name}.

%package doc
Summary:        Documentation for speech-dispatcher
License:        GPLv2+
Requires:       %{name} = %{version}-%{release}
BuildArch: noarch

%description doc
speechd documentation

%package utils
Summary:        Various utilities for speech-dispatcher
License:        GPLv2+
Requires:       %{name} = %{version}-%{release} python3-speechd = %{version}-%{release}

%description utils
Various utilities for speechd

%package espeak-ng
Summary:        Speech Dispatcher espeak-ng module
Requires:       %{name} = %{version}-%{release}

%description espeak-ng
This package contains the espeak-ng output module for Speech Dispatcher.

%package festival
Summary:        Speech Dispatcher festival module
Requires:       %{name} = %{version}-%{release} festival-freebsoft-utils

%description festival
This package contains the festival output module for Speech Dispatcher.

%package flite
Summary:        Speech Dispatcher flite module
Requires:       %{name} = %{version}-%{release} flite

%description flite
This package contains the flite output module for Speech Dispatcher.

%package -n python3-speechd
Summary:        Python 3 Client API for speech-dispatcher
License:        GPLv2+
Requires:       %{name} = %{version}-%{release}

%description -n python3-speechd
Python 3 module for speech-dispatcher

%prep
%autosetup -n %{name}-%{version} -a1 -p1

%build
%configure \
    --disable-static \
    --with-alsa \
    --with-pulse \
    --with-libao \
    --with-flite \
    --with-espeak-ng \
    --without-oss \
    --without-nas \
    --without-espeak \
    --with-kali=no \
    --with-baratinoo=no \
    --with-ibmtts=no \
    --with-voxin=no \
    --sysconfdir=%{_sysconfdir} \
    --with-default-audio-method=pulse \
    --with-module-bindir=%{_libdir}/speech-dispatcher-modules/ \
    %{nil}

%make_build

%install
%make_install

install -p -m 0644 sound-icons-0.1/* %{buildroot}%{_datadir}/sounds/%{name}/

%find_lang speech-dispatcher

rm -f %{buildroot}%{_infodir}/dir

find %{buildroot} -name '*.la' -delete

mkdir -p %{buildroot}%{_sysconfdir}/speech-dispatcher/clients
mkdir -p %{buildroot}%{_sysconfdir}/speech-dispatcher/modules
mv %{buildroot}%{_datadir}/speech-dispatcher/conf/speechd.conf \
    %{buildroot}%{_sysconfdir}/speech-dispatcher/
mv %{buildroot}%{_datadir}/speech-dispatcher/conf/clients/* \
    %{buildroot}%{_sysconfdir}/speech-dispatcher/clients
mv %{buildroot}%{_datadir}/speech-dispatcher/conf/modules/* \
    %{buildroot}%{_sysconfdir}/speech-dispatcher/modules

mkdir -p -m 0700 %{buildroot}%{_localstatedir}/log/speech-dispatcher/

desktop-file-validate %{buildroot}/%{_datadir}/speech-dispatcher/conf/desktop/speechd.desktop

sed 's/# AudioOutputMethod "pulse,alsa"/AudioOutputMethod "pulse,alsa"/' \
    %{buildroot}%{_sysconfdir}/speech-dispatcher/speechd.conf

%post 
%systemd_post speech-dispatcherd.service

%postun
%systemd_postun_with_restart speech-dispatcherd.service

%preun
%systemd_preun speech-dispatcherd.service

%files -f speech-dispatcher.lang
%license COPYING.LGPL
%doc NEWS README.md
%dir %{_sysconfdir}/speech-dispatcher/
%dir %{_sysconfdir}/speech-dispatcher/clients
%dir %{_sysconfdir}/speech-dispatcher/modules
%config(noreplace) %{_sysconfdir}/speech-dispatcher/speechd.conf
%config(noreplace) %{_sysconfdir}/speech-dispatcher/clients/*.conf
%config(noreplace) %{_sysconfdir}/speech-dispatcher/modules/*.conf
%dir %attr(0700, root, root) %{_localstatedir}/log/speech-dispatcher/
%{_bindir}/speech-dispatcher
%{_libdir}/libspeechd.so.2
%{_libdir}/libspeechd.so.2.6.0
%dir %{_libdir}/speech-dispatcher-modules/
%{_libdir}/speech-dispatcher-modules/sd_cicero
%{_libdir}/speech-dispatcher-modules/sd_dummy
%{_libdir}/speech-dispatcher-modules/sd_generic
%dir %{_libdir}/speech-dispatcher
%{_libdir}/speech-dispatcher/spd*.so
%{_datadir}/speech-dispatcher/
%{_datadir}/sounds/speech-dispatcher
%{_mandir}/man1/speech-dispatcher.1*
%{_unitdir}/speech-dispatcherd.service
%exclude %{_sysconfdir}/speech-dispatcher/modules/espeak*.conf
%exclude %{_sysconfdir}/speech-dispatcher/modules/festival.conf
%exclude %{_sysconfdir}/speech-dispatcher/modules/flite.conf

%files devel
%{_includedir}/*
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*.pc

%files doc
%{_infodir}/*

%files utils
%{_bindir}/spd-conf
%{_bindir}/spd-say
%{_bindir}/spdsend
%{_mandir}/man1/spd-conf.1*
%{_mandir}/man1/spd-say.1*

%files espeak-ng
%config(noreplace) %{_sysconfdir}/speech-dispatcher/modules/espeak-ng.conf
%{_libdir}/speech-dispatcher-modules/sd_espeak-ng
%{_libdir}/speech-dispatcher-modules/sd_espeak-ng-mbrola

%files festival
%config(noreplace) %{_sysconfdir}/speech-dispatcher/modules/festival.conf
%{_libdir}/speech-dispatcher-modules/sd_festival

%files flite
%config(noreplace) %{_sysconfdir}/speech-dispatcher/modules/flite.conf
%{_libdir}/speech-dispatcher-modules/sd_flite

%files -n python3-speechd
%{python3_sitearch}/speechd*

%changelog
* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.11.4-7
- Rebuilt for loongarch release

* Mon Nov 13 2023 cunshunxia@tencent.com - 0.11.4-6
- Rebuilt for libsndfile 1.2.0-4

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.11.4-5
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.11.4-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.11.4-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.11.4-2
- Rebuilt for OpenCloudOS Stream 23

* Thu Mar 30 2023 Shuo Wang <abushwang@tencent.com> - 0.11.4-1
- initial build
